@@ -2,9 +2,10 @@ import curses
 
 
 class Interface:
-    def __init__(self, application, components, no_cursor=False):
+    def __init__(self, application, components, end_components, no_cursor=False):
         self.application = application
         self.components = components
+        self.end_components = end_components
         self.no_cursor = no_cursor
         self.colors = True
 
@@ -29,6 +30,10 @@ class Interface:
         for component in self.components:
             component.paint(screen, self.application)
 
+    def draw_end(self, screen):
+        for component in self.end_components:
+            component.paint(screen, self.application)
+
     def __call__(self, screen):
         """
         Main running loop
@@ -42,3 +47,9 @@ class Interface:
         while self.application.running():
             self.update(screen)
             self.application.action(screen)
+
+        if self.application.summarize():
+            screen.clear()
+            curses.curs_set(0)
+            self.draw_end(screen)
+            self.application.action(screen)
